@@ -713,6 +713,9 @@ class IdenticalChainsAndEntityId(PDBeSolrSearch):
         documents = self.exec_query("pdb_id,entity_id,chain_id,assembly_composition", [('pdb_id', pdbcode)])
 
         for i in range(len(documents)):
+            if 'chain_id' not in documents[i] or 'entity_id' not in documents[i]:
+                self.results = (None, None)
+                continue
             chain_id = documents[i]['chain_id']
             ent_id = documents[i]['entity_id']
             if chain in chain_id:
@@ -950,6 +953,14 @@ class UniprotInfo():
                 seq += line if not line.startswith('>') else ''
         return seq
 
+    def get_overall_length(self):
+        url_from = 'https://www.uniprot.org/uniprot/{}.txt'.format(self.uniid)
+        with urllib.request.urlopen(url_from) as url:
+            first_line = url.read().decode().split('\n')[0]
+            length = int(first_line.split(';')[1].strip().split(' ')[0])
+            return length
+
+
     def get_title(self):
         url_from = 'https://www.uniprot.org/uniprot/{}.txt'.format(self.uniid)
         title = None
